import style from "./style.module.css";
import { Link } from "react-router-dom";
import React, { useState } from "react";
import {
  Divider,
  IconButton,
  Menu,
  MenuItem,
  Paper,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
} from "@mui/material";
import MoreHorizIcon from "@mui/icons-material/MoreHoriz";
import { useSelectorFileList } from "../../store/fileList";
import fileSize from "filesize";
import { downloadFile } from "../../telegram/telegram";

enum ContentType {
  File,
  Share,
  SafeBox,
  Recycled,
}

function Login() {
  let [type, setType] = useState(ContentType.File);

  return (
    <div
      style={{
        width: "100vw",
        height: "100vh",
        display: "flex",
        alignItems: "center",
      }}
    >
      <div className={style.menu}>
        <li onClick={() => setType(ContentType.File)}>文件</li>
        <li onClick={() => setType(ContentType.Share)}>分享</li>
        <li onClick={() => setType(ContentType.SafeBox)}>保险箱</li>
        <li onClick={() => setType(ContentType.Recycled)}>回收站</li>
        <Link to={`/`}>
          <div className={style.logo}>LOGO</div>
        </Link>
      </div>
      <div className={style.content}>
        {type === ContentType.File && <File />}
        {type === ContentType.Share && <Share />}
        {type === ContentType.SafeBox && <SafeBox />}
        {type === ContentType.Recycled && <Recycled />}
      </div>
    </div>
  );
}

function File() {
  let [anchorEl, setAnchorEl] = useState<null | HTMLElement>(null);
  let [waitDownloadFile, setWaitDownloadFile] = useState(null);
  let fileList = useSelectorFileList();

  const open = Boolean(anchorEl);

  let handleClick = (index: number) => {
    return (event: React.MouseEvent<HTMLButtonElement>) => {
      console.log("index", index);
      setWaitDownloadFile(fileList[index]);
      setAnchorEl(event.currentTarget);
    };
  };
  let handleClose = () => {
    setAnchorEl(null);
  };

  let Download = () => {
    downloadFile(waitDownloadFile)
      .then((res) => {
        console.log("res", res);
      })
      .catch((error) => {
        console.log("download error:", error);
        alert(error);
      });
  };
  return (
    <div
      style={{
        display: "flex",
        alignItems: "center",
        height: "100%",
        width: "100%",
      }}
    >
      <Paper sx={{ padding: "100px", width: "100%" }}>
        <TableContainer sx={{ backgroundColor: "#f2f2f2", height: 500 }}>
          <Table aria-label={"文件列表"}>
            <TableHead>
              <TableRow>
                <TableCell sx={{ width: "70%" }}>名称</TableCell>
                <TableCell>修改时间</TableCell>
                <TableCell>大小</TableCell>
              </TableRow>
            </TableHead>
            <TableBody>
              {fileList.map((item: any, index: number) => {
                return (
                  <TableRow key={item.id} sx={{ cursor: "pointer" }}>
                    <TableCell sx={{ position: "relative" }}>
                      {item.attributes[0].file_name}
                      <IconButton
                        sx={{
                          position: "absolute",
                          right: 20,
                          top: "50%",
                          transform: "translate(-50%,-50%)",
                        }}
                        onClick={handleClick(index)}
                      >
                        <MoreHorizIcon />
                      </IconButton>
                    </TableCell>
                    <TableCell>
                      {
                        // @ts-ignore
                        new Date(item.date * 1000).Format("yyyy-MM-dd hh:mm:ss")
                      }
                    </TableCell>
                    <TableCell>{fileSize(item.size)}</TableCell>
                  </TableRow>
                );
              })}
            </TableBody>
          </Table>
        </TableContainer>
      </Paper>
      <Menu
        open={open}
        id="basic-menu"
        anchorEl={anchorEl}
        onClose={handleClose}
      >
        <MenuItem onClick={Download}>下载</MenuItem>
        <MenuItem onClick={handleClose}>分享</MenuItem>
        <Divider />
        <MenuItem onClick={handleClose}>重命名</MenuItem>
        <MenuItem onClick={handleClose}>移动</MenuItem>
        <MenuItem onClick={handleClose}>移至保险箱</MenuItem>
        <MenuItem onClick={handleClose}>查看详细信息</MenuItem>
        <MenuItem onClick={handleClose}>删除</MenuItem>
      </Menu>
    </div>
  );
}

function Share() {
  return <div>分享</div>;
}

function SafeBox() {
  return <div>保险箱</div>;
}

function Recycled() {
  return <div>回收站</div>;
}

export default Login;
