import { useEffect, useState } from "react";
import { getMe } from "../../telegram/user";
import { HomeButton } from "../../component/homeButton";
import style from "./style.module.css";
import { Box, Drawer } from "@mui/material";
import { HomeMenu } from "../../component/homeMenu";
import { HomeSignIn } from "../../component/homeSignIn";
import { useDispatch } from "react-redux";
import { useSelectorIsLoggedIn, useSelectorUser } from "../../store/user";
import { login } from "../../store/user";

function Home() {
  // let [isSignIn, setIsSignIn] = useState(false);
  const dispatch = useDispatch();
  let isSignIn = useSelectorIsLoggedIn();
  let [isOpenSignIn, setIsOpenSignIn] = useState(false);
  let user = useSelectorUser();

  useEffect(
    function () {
      getMe()
        .then(function (user) {
          // 已登录
          dispatch(login(user));
        })
        .catch(function (error) {
          if (error.code === 401) {
            // Unauthorized
          }
          console.log(error);
        });
    },
    [dispatch]
  );

  return (
    <div className={style.box}>
      <div className={style.homeButton}>
        <HomeButton
          isSignIn={isSignIn}
          onNotSignIn={() => {
            setIsOpenSignIn(true);
          }}
        />
      </div>
      <HomeMenu
        className={style.homeMenu}
        isSignIn={isSignIn}
        onOpenSignIn={() => {
          setIsOpenSignIn(true);
        }}
      />
      {user.user && <div>{user.user.username}</div>}
      <Drawer
        anchor={"right"}
        open={isOpenSignIn && !isSignIn}
        onClose={() => {
          setIsOpenSignIn(false);
        }}
        ModalProps={{
          keepMounted: true,
        }}
        transitionDuration={500}
      >
        <Box sx={{ width: "600px", height: "100%" }}>
          <div className={style.homeSignIn}>
            <HomeSignIn />
          </div>
        </Box>
      </Drawer>
    </div>
  );
}

export default Home;
